@@ -2,7 +2,7 @@
 # @Time    : 2023-11-15 14:14
 # @Author  : Kem
 # @Desc    :
-
+import contextlib
 import copy
 import re
 import urllib.parse
@@ -27,9 +27,9 @@ class Downloader(AbstractDownloader):
     """
 
     def __init__(
-        self,
-        impersonate: Optional[Union[requests.BrowserType, str]] = None,
-        options: Optional[dict] = None,
+            self,
+            impersonate: Optional[Union[requests.BrowserType, str]] = None,
+            options: Optional[dict] = None,
     ):
         if isinstance(impersonate, requests.BrowserType):
             impersonate = impersonate.value
@@ -37,7 +37,7 @@ class Downloader(AbstractDownloader):
         self.impersonate = impersonate
         self.options = options or {}
 
-    def fetch(self, request: Request) -> Response:
+    def fetch(self, request: Union[Request, dict]) -> Response:
         """
         真使用 requests 发送请求并获取响应
 
@@ -45,6 +45,7 @@ class Downloader(AbstractDownloader):
         :return: `Response`
 
         """
+        request: Request
         res = Response.make_response(request=request)
         options = {
             **self.options,
@@ -57,7 +58,7 @@ class Downloader(AbstractDownloader):
             "timeout": 5 if request.timeout is ... else request.timeout,
             "allow_redirects": False,
             "proxies": request.proxies
-            and {"http": request.proxies, "https": request.proxies},  # noqa
+                       and {"http": request.proxies, "https": request.proxies},  # noqa
             "verify": request.options.get("verify", False),
             "impersonate": request.options.get("impersonate") or self.impersonate,
             **request.options.get("$options", {}),
@@ -68,46 +69,50 @@ class Downloader(AbstractDownloader):
 
         if request.use_session:
             session = request.get_options("$session") or self.get_session()
+            ctx = contextlib.nullcontext()
         else:
-            session = requests
+            session = requests.Session()
+            ctx = session
 
-        while True:
-            assert _redirect_count < 999, "已经超过最大重定向次数: 999"
-            response = session.request(**{**options, "url": next_url})
-            last_url, next_url = (
-                next_url,
-                response.headers.get("location") or response.headers.get("Location"),
-            )
-            if request.allow_redirects and next_url:
-                next_url = urllib.parse.urljoin(response.url, next_url)
-                _redirect_count += 1
-                res.history.append(
-                    Response(
-                        content=response.content,
-                        headers=response.headers,
-                        cookies=Cookies.by_jar(response.cookies.jar),
-                        url=response.url,
-                        status_code=response.status_code,
-                        request=Request(
-                            url=last_url,
-                            method=request.method,
-                            headers=copy.deepcopy(options.get("headers")),  # type: ignore
-                        ),
-                    )
+        with ctx:
+
+            while True:
+                assert _redirect_count < 999, "已经超过最大重定向次数: 999"
+                response = session.request(**{**options, "url": next_url})
+                last_url, next_url = (
+                    next_url,
+                    response.headers.get("location") or response.headers.get("Location"),
                 )
-                request.options.get("$referer", False) and options["headers"].update(
-                    Referer=response.url
-                )  # type: ignore
+                if request.allow_redirects and next_url:
+                    next_url = urllib.parse.urljoin(response.url, next_url)
+                    _redirect_count += 1
+                    res.history.append(
+                        Response(
+                            content=response.content,
+                            headers=response.headers,
+                            cookies=Cookies.by_jar(response.cookies.jar),
+                            url=response.url,
+                            status_code=response.status_code,
+                            request=Request(
+                                url=last_url,
+                                method=request.method,
+                                headers=copy.deepcopy(options.get("headers")),  # type: ignore
+                            ),
+                        )
+                    )
+                    request.options.get("$referer", False) and options["headers"].update(
+                        Referer=response.url
+                    )  # type: ignore
 
-            else:
-                res.content = response.content
-                res.headers = response.headers  # type: ignore
-                res.cookies = Cookies.by_jar(response.cookies.jar)
-                res.url = response.url
-                res.status_code = response.status_code
-                res.request = request
+                else:
+                    res.content = response.content
+                    res.headers = response.headers  # type: ignore
+                    res.cookies = Cookies.by_jar(response.cookies.jar)
+                    res.url = response.url
+                    res.status_code = response.status_code
+                    res.request = request
 
-                return res
+                    return res
 
     def make_session(self) -> requests.Session:
         return requests.Session()
@@ -116,12 +121,12 @@ class Downloader(AbstractDownloader):
         resp = super().exception(request, error)
         code = CURL_CODE.search(str(error))
         if code and code.group(1) in (
-            # Could not resolve proxy. The given proxy host could not be resolved.
-            "5"
-            # Failed to connect() to host or proxy.
-            "7"
-            # Proxy handshake error
-            "97"
+                # Could not resolve proxy. The given proxy host could not be resolved.
+                "5"
+                # Failed to connect() to host or proxy.
+                "7"
+                # Proxy handshake error
+                "97"
         ):
             resp.error = "ProxyError"
         return resp
