@@ -20,11 +20,12 @@ from bricks.utils import pandora
 
 warnings.filterwarnings("ignore")
 # 设置 requests 最大的响应头的长度 为 1000
-http.client._MAXHEADERS = 1000 # type: ignore
+http.client._MAXHEADERS = 1000  # type: ignore
 
 pandora.require("httpx")
 
 import httpx  # noqa: E402
+
 PROXY_ERROR_PARRTEN = re.compile(r"\[Errno 111\] Connection refused")
 
 
@@ -39,7 +40,7 @@ class Downloader(AbstractDownloader):
     def __init__(self, options: Optional[dict] = None):
         self.options = options or {}
 
-    def fetch(self, request: Request) -> Response:
+    def fetch(self, request: Union[Request, dict]) -> Response:
         """
         真使用 requests 发送请求并获取响应
 
@@ -116,7 +117,7 @@ class Downloader(AbstractDownloader):
                     )
                     request.options.get("$referer", False) and options[
                         "headers"
-                    ].update(Referer=str(response.url)) # type: ignore
+                    ].update(Referer=str(response.url))  # type: ignore
 
                 else:
                     res.content = response.content
@@ -128,7 +129,7 @@ class Downloader(AbstractDownloader):
 
                     return res
         finally:
-            not request.use_session and session.close() # type: ignore
+            not request.use_session and session.close()  # type: ignore
 
     def make_session(self, **options):
         return httpx.Client(**options)
@@ -147,4 +148,4 @@ if __name__ == "__main__":
             url="http://127.0.0.1:5555", proxies="http://127.0.0.1:7890", timeout=20
         )
     )
-    print(rsp, rsp.error, rsp.reason)
\ No newline at end of file
+    print(rsp, rsp.error, rsp.reason)
