@@ -163,8 +163,8 @@ class Spider(air.Spider):
                 func=engine,
                 args=node_args,
                 kwargs={**kwargs, **node_kwargs},
-                annotations={Context: context},
-                namespace={"context": context},
+                annotations=context.annotations,
+                namespace=context.namespace,
             )
             layout = layout.render(seeds)
 
@@ -211,18 +211,8 @@ class Spider(air.Spider):
                 func=context.response.extract,
                 args=[engine.lower(), *args],
                 kwargs=kwargs,
-                annotations={
-                    Context: context,
-                    Response: context.response,
-                    Request: context.request,
-                    Item: context.seeds,
-                },
-                namespace={
-                    "context": context,
-                    "response": context.response,
-                    "request": context.request,
-                    "seeds": context.seeds,
-                },
+                annotations=context.annotations,
+                namespace=context.namespace,
             )
         else:
             if not callable(engine):
@@ -232,18 +222,8 @@ class Spider(air.Spider):
                 func=engine,
                 args=args,
                 kwargs=kwargs,
-                annotations={
-                    Context: context,
-                    Response: context.response,
-                    Request: context.request,
-                    Item: context.seeds,
-                },
-                namespace={
-                    "context": context,
-                    "response": context.response,
-                    "request": context.request,
-                    "seeds": context.seeds,
-                },
+                annotations=context.annotations,
+                namespace=context.namespace,
             )
 
         pandora.clean_rows(
@@ -267,20 +247,8 @@ class Spider(air.Spider):
             if callable(node.match):
                 ok = pandora.invoke(
                     func=node.match,
-                    annotations={
-                        Context: context,
-                        Response: context.response,
-                        Request: context.request,
-                        Item: context.seeds,
-                        Items: context.items,
-                    },
-                    namespace={
-                        "context": context,
-                        "response": context.response,
-                        "request": context.request,
-                        "seeds": context.seeds,
-                        "items": context.items,
-                    },
+                    annotations=context.annotations,
+                    namespace=context.namespace,
                 )
 
             elif isinstance(node.match, str):
@@ -317,20 +285,8 @@ class Spider(air.Spider):
                     func=engine,
                     args=args,
                     kwargs=kwargs,
-                    annotations={
-                        Context: context,
-                        Response: context.response,
-                        Request: context.request,
-                        Item: context.seeds,
-                        Items: context.items,
-                    },
-                    namespace={
-                        "context": context,
-                        "response": context.response,
-                        "request": context.request,
-                        "seeds": context.seeds,
-                        "items": context.items,
-                    },
+                    annotations=context.annotations,
+                    namespace=context.namespace,
                 )
             finally:
                 context.items = backup
