@@ -36,7 +36,6 @@ PYPI_MIRROR = {
     "pypi": "https://pypi.org/simple/",
 }
 
-
 better_exceptions.MAX_LENGTH = None
 exec_formatter = better_exceptions.ExceptionFormatter(
     colored=False,
@@ -97,32 +96,56 @@ def load_objects(path_or_reference, reload=False):
         raise ImportError(f"无法导入指定路径或引用: {path_or_reference}")
 
 
+def _build_by_pip(package: str, mirror: str = "", options: Dict[str, str] = None):
+    mirror and options.setdefault("-i", mirror)
+    cmd = [sys.executable, "-m", "pip", "install"]
+    for k, v in options.items():
+        k and cmd.append(k)
+        v and cmd.append(v)
+    cmd.append(package)
+    return cmd
+
+
+def _build_by_uv(package: str, mirror: str = "", options: Dict[str, str] = None):
+    mirror and options.setdefault("--default-index", mirror)
+    cmd = [sys.executable, "-m", "uv", "add"]
+    for k, v in options.items():
+        k and cmd.append(k)
+        v and cmd.append(v)
+    cmd.append(package)
+    return cmd
+
+
 def require(
-    package_spec: str,
-    action: Literal["raise", "fix"] = "fix",
-    mirror_sources: str = "TUNA",
-    pip_kwargs: Dict[str, str] = None,
+        package_spec: str,
+        action: Literal["raise", "fix"] = "fix",
+        mirror_sources: str = "TUNA",
+        build_options: Dict[str, str] = None,
+        mode: Union[Literal["pip", "uv"], str] = None
 ) -> str:
     """
     依赖 python 包
 
+    :param mode: pip / uv / anything ?
     :param action: 依赖操作, 若为 fix 则自动下载对应包,
     :param package_spec: pymongo==4.6.0 / pymongo
     :param mirror_sources : pip 源, 内置有 "TUNA", "USTC", "Aliyun", "Tencent", "Huawei", "pypi", 可以传自己的源进来
-    :param pip_kwargs: pip 的一些参数, 如 --trusted-host, 单独的参数可以使用 {"--upgrade": ""} 这种方式
+    :param build_options: pip 的一些参数, 如 --trusted-host, 单独的参数可以使用 {"--upgrade": ""} 这种方式
     :return: 安装的包版本号
     """
     # 分离包名和版本规范
+    mode = mode or os.environ.get('REQUIRE_MODE', 'pip')
     package_spec = re.sub(r"\s+", "", package_spec)
     match = PACKAGE_REGEX.match(package_spec)
     mirror_sources = PYPI_MIRROR.get(mirror_sources, mirror_sources)
-    pip_kwargs = pip_kwargs or {}
+    build_options = build_options or {}
 
     assert match, ValueError(f"无效的包规范: {package_spec}")
     assert not mirror_sources or PIPY_REGEX.match(mirror_sources), ValueError(
         f"无效的镜像源: {mirror_sources}"
     )
-    mirror_sources and pip_kwargs.setdefault("-i", mirror_sources)
+
+    mode == "uv" and require("uv", action="raise")
 
     package, operator, required_version = match.groups()
 
@@ -133,7 +156,7 @@ def require(
         from bricks.utils.package import parse as version_parse  # noqa
 
         if required_version and not eval(
-            f"version_parse({installed_version!r}) {operator} version_parse({required_version!r})"
+                f"version_parse({installed_version!r}) {operator} version_parse({required_version!r})"
         ):
             raise importlib_metadata.PackageNotFoundError
         else:
@@ -141,16 +164,15 @@ def require(
 
     except importlib_metadata.PackageNotFoundError:
         # 包没有安装或版本不符合要求
-        install_command = package_spec if required_version else package
-        cmd = [sys.executable, "-m", "pip", "install"]
-        for k, v in pip_kwargs.items():
-            k and cmd.append(k)
-            v and cmd.append(v)
-        cmd.append(install_command)
+        builder_func = f'_build_by_{mode}'
+        builder: Callable[[str, str, Dict[str, str]], str] = globals().get(builder_func)
+        if not callable(builder):
+            raise ValueError(f"不支持的安装模式: {mode}")
+
+        cmd: str = builder(package_spec if required_version else package, mirror_sources, build_options)
+
         if action == "raise":
-            raise importlib_metadata.PackageNotFoundError(
-                f"依赖包不符合要求, 请使用以下命令安装: {' '.join(cmd)}"
-            )
+            raise importlib_metadata.PackageNotFoundError(f"依赖包不符合要求, 请使用以下命令安装: {' '.join(cmd)}")
         else:
             logger.debug(f"依赖包不符合要求, 自动修正, 命令: {' '.join(cmd)}")
             subprocess.check_call(cmd)
@@ -158,12 +180,12 @@ def require(
 
 
 def invoke(
-    func,
-    args=None,
-    kwargs: dict = None,
-    annotations: dict = None,
-    namespace: dict = None,
-    ignore: list = None,
+        func,
+        args=None,
+        kwargs: dict = None,
+        annotations: dict = None,
+        namespace: dict = None,
+        ignore: list = None,
 ):
     """
     调用函数, 自动修正参数
@@ -181,12 +203,12 @@ def invoke(
 
 
 def prepare(
-    func: Callable,
-    args=None,
-    kwargs: dict = None,
-    annotations: dict = None,
-    namespace: dict = None,
-    ignore: list = None,
+        func: Callable,
+        args=None,
+        kwargs: dict = None,
+        annotations: dict = None,
+        namespace: dict = None,
+        ignore: list = None,
 ):
     """
     筛选出函数的相关参数
@@ -243,9 +265,9 @@ def prepare(
 
         # 参数类型存在于 annotations, 并且还可以从 args 里面取值, 并且刚好取到的对应的值也是当前类型 -> 直接从 args 里面取
         elif (
-            param.annotation in annotations
-            and index < len(args)
-            and type(args[index]) is param.annotation
+                param.annotation in annotations
+                and index < len(args)
+                and type(args[index]) is param.annotation
         ):
             value = args[index]
             index += 1
@@ -280,10 +302,10 @@ def prepare(
 
 
 def iterable(
-    _object: Any,
-    enforce=(dict, str, bytes, collections.UserDict, Mapping),
-    exclude=(),
-    convert_null=True,
+        _object: Any,
+        enforce=(dict, str, bytes, collections.UserDict, Mapping),
+        exclude=(),
+        convert_null=True,
 ) -> List[Any]:
     """
     用列表将 `exclude` 类型中的其他类型包装起来
@@ -320,7 +342,7 @@ def first(_object, default=None):
 
 
 def json_or_eval(
-    text, jsonp=False, errors: Literal["strict", "ignore"] = "strict", _step=0, **kwargs
+        text, jsonp=False, errors: Literal["strict", "ignore"] = "strict", _step=0, **kwargs
 ) -> Union[dict, list, str]:
     """
     通过字符串获取 python 对象，支持json类字符串和jsonp字符串
@@ -414,9 +436,9 @@ def clean_rows(*rows: dict, **layout):
     def _show(rule: dict, data: dict):
         for key, flag in rule.items():
             if (
-                callable(flag)
-                and not invoke(flag, args=[data.get(key, None)], kwargs={"row": row})
-                or not flag
+                    callable(flag)
+                    and not invoke(flag, args=[data.get(key, None)], kwargs={"row": row})
+                    or not flag
             ):
                 rule.pop(key, None)
 
@@ -445,12 +467,12 @@ def clean_rows(*rows: dict, **layout):
 
 
 def with_metaclass(
-    singleton: bool = False,
-    thread_safe: bool = True,
-    key_maker: Callable = None,
-    autonomous: (Tuple[Union[str, Callable]], List[Union[str, Callable]]) = (),
-    wrappers: Union[dict, str] = None,
-    modded: dict = None,
+        singleton: bool = False,
+        thread_safe: bool = True,
+        key_maker: Callable = None,
+        autonomous: Union[Tuple[Union[str, Callable]], List[Union[str, Callable]]]= (),
+        wrappers: Union[dict, str] = None,
+        modded: dict = None,
 ):
     """
     魔改 class
@@ -558,3 +580,7 @@ def guess(_object: Any) -> Any:
 
     else:
         return _object
+
+
+if __name__ == '__main__':
+    require("requests", mode='uv')
